epistoch.utils package
======================

.. automodule:: epistoch.utils
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

epistoch.utils.plotting module
------------------------------

.. automodule:: epistoch.utils.plotting
   :members:
   :undoc-members:
   :show-inheritance:

epistoch.utils.stats module
---------------------------

.. automodule:: epistoch.utils.stats
   :members:
   :undoc-members:
   :show-inheritance:

epistoch.utils.utils module
---------------------------

.. automodule:: epistoch.utils.utils
   :members:
   :undoc-members:
   :show-inheritance:
